@@ -322,79 +322,6 @@ R_parseURI(SEXP r_uri)
   return(ans);
 }
 
-void R_xmlFreeDoc(SEXP ref)
-{
-  xmlDocPtr doc;
-  doc = (xmlDocPtr) R_ExternalPtrAddr(ref);
-
-  if(doc && !IS_NOT_OUR_DOC_TO_TOUCH(doc)) {
-      int *val;
-      val = doc->_private;
-      if(val) {
-	  (*val)--;
-	  if(*val) {
-#ifdef R_XML_DEBUG
-	      fprintf(stderr, "Not freeing XML document %p (%s); still has %d references in the wild\n", doc, doc->URL ? doc->URL : "?", *val);
-#endif
-	      R_ClearExternalPtr(ref);
-	      return;
-	  }
-      }
-      
-#ifdef R_XML_DEBUG
-      const xmlChar *url = doc->URL ? doc->URL : (doc->name ? doc->name : (const xmlChar *)"?? (internally created)");
-      fprintf(stderr, "Cleaning up document %p, %s, has children %d\n", (void *) doc, url, (int) (doc->children != NULL));
-#endif
-      if(val) {
-	  free(val);
-	  doc->_private = NULL;
-
-#ifdef R_XML_DEBUG
-	  fprintf(stderr, "Freeing the XML doc %p\n", doc);
-#endif
-          xmlFreeDoc(doc);
-          R_numXMLDocsFreed++;
-     } /* was before the xmlFreeDoc so that that was unconditional.*/
-  }
-  R_ClearExternalPtr(ref);
-}
-
-
-SEXP
-RS_XML_freeDoc(SEXP ref)
-{
-    R_xmlFreeDoc(ref); 
-    return(R_NilValue);
-}
-
-
-/* This is a finalizer that removes the nodes and disassociates the
-   node and the document and then frees the document structure.
-
-   Does xmlFreeDoc() deal with the URL and name fields in the doc?
-
-XXX With the nodes and document under garbage collection, do we really
-need this?
-*/
-void R_xmlFreeDocLeaveChildren(SEXP ref)
-{
- xmlDocPtr doc;
- doc = (xmlDocPtr) R_ExternalPtrAddr(ref);
-
-  if(doc) {
-      xmlNodePtr tmp;
-#ifdef R_XML_DEBUG
-      const xmlChar *url = doc->URL ? doc->URL : (doc->name ? doc->name : (const xmlChar *) "?? (internally created)");
-      fprintf(stderr, "Cleaning up document but not children: %p, %s\n", (void *) doc, url);
-#endif
-      tmp = doc->children;
-      xmlUnlinkNode(doc->children);
-      tmp->doc = NULL;
-      xmlFreeDoc(doc);
-      R_numXMLDocsFreed++;
-  }
-  R_ClearExternalPtr(ref);
-}
 
 
 
